@@ -1,11 +1,17 @@
 """Interact with the Censys Seeds, Assets, and Logbook APIs."""
 from typing import Optional
 
-from .assets import CertificatesAssets, DomainsAssets, HostsAssets, SubdomainsAssets
+from .assets import (
+    CertificatesAssets,
+    DomainsAssets,
+    HostsAssets,
+    SubdomainsAssets,
+    WebEntitiesAssets,
+)
 from .clouds import Clouds
 from .events import Events
 from .inventory import InventorySearch
-from .risks import Risksv2
+from .risks import Risks
 from .seeds import Seeds
 
 
@@ -25,8 +31,9 @@ class AsmClient:
         self.domains = DomainsAssets(api_key, **kwargs)
         self.events = Events(api_key, **kwargs)
         self.clouds = Clouds(api_key, **kwargs)
-        self.risks = Risksv2(api_key, **kwargs)
+        self.risks = Risks(api_key, **kwargs)
         self.inventory = InventorySearch(api_key, **kwargs)
+        self.web_entities = WebEntitiesAssets(api_key, **kwargs)
 
         # Save the arguments for parameterized client usage
         self.__api_kwargs = kwargs
